# scientistshiny : Python library for multidimensional analysis

## About scientistshiny

**scientistshiny** is a `Python` package to easily improve multivariate Exploratory Data Analysis graphs.

## Installation

### Dependencies

scientistshiny requires 

```
scientisttools>=0.1.3
numpy>=1.26.2
matplotlib>=3.5.3
scikit-learn>=1.2.2
pandas>=1.5.3
mapply>=0.1.21
plotnine>=0.10.1
plydata>=0.4.3
pingouin>=0.5.3
scientistmetrics>=0.0.3
ggcorrplot>=0.0.2
```

### User installation

You can install scientisttools using `pip` :

```
pip install scientistshiny
```

## Author

Duvérier DJIFACK ZEBAZE ([duverierdjifack@gmail.com](duverierdjifack@gmail.com))
